@@ -1,5 +1,5 @@
 /* This file is part of vmod-sql
-   Copyright (C) 2013-2018 Sergey Poznyakoff
+   Copyright (C) 2013-2020 Sergey Poznyakoff
 
    Vmod-sql is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -121,7 +121,7 @@ make_key()
 }
 
 int
-sql_event(VRT_CTX, struct vmod_priv *priv, enum vcl_event_e e)
+vmod_sql_event(VRT_CTX, struct vmod_priv *priv, enum vcl_event_e e)
 {
 	if (e == VCL_EVENT_LOAD) {
 		pthread_once(&thread_once, make_key);
